Loading methods
---------------

Methods for listing and loading datasets and metrics:

Datasets
~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: datasets.list_datasets

.. autofunction:: datasets.load_dataset

.. autofunction:: datasets.load_from_disk

.. autofunction:: datasets.load_dataset_builder

.. autofunction:: datasets.get_dataset_config_names

.. autofunction:: datasets.get_dataset_infos

.. autofunction:: datasets.get_dataset_split_names

.. autofunction:: datasets.inspect_dataset

Metrics
~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: datasets.list_metrics

.. autofunction:: datasets.load_metric

.. autofunction:: datasets.inspect_metric
